@@ -204,7 +204,7 @@ codec_cap_list_free (GList *list)
  * network  -> rtp depayloader -> N* -> output (soundcard)
  * media_type defines if we want audio or video codecs
  *
- * Returns : a #GList of #CodecBlueprint or NULL on error
+ * Returns: a #GList of #CodecBlueprint or NULL on error
  */
 GList *
 fs_rtp_blueprints_get (FsMediaType media_type, GError **error)
@@ -917,8 +917,10 @@ codec_cap_list_intersect (GList *list1, GList *list2)
               copy_element_list (codec_cap2->element_list2));
 
           intersection_list = g_list_append (intersection_list, item);
-          if (rtp_intersection)
+          if (rtp_intersection) {
+            gst_caps_unref (intersection);
             break;
+          }
         }
       } else {
         if (rtp_intersection)
@@ -1142,8 +1144,7 @@ create_codec_cap_list (GstElementFactory *factory,
       CodecCap *entry = NULL;
       GList *found_item = NULL;
       GstStructure *structure = gst_caps_get_structure (caps, i);
-      GstCaps *cur_caps =
-          gst_caps_new_full (gst_structure_copy (structure), NULL);
+      GstCaps *cur_caps = NULL;
 
       /* FIXME fix this in gstreamer! The rtpdepay element is bogus, it claims to
        * be a depayloader yet has application/x-rtp on both sides and does
@@ -1159,6 +1160,8 @@ create_codec_cap_list (GstElementFactory *factory,
         continue;
       }
 
+      cur_caps = gst_caps_new_full (gst_structure_copy (structure), NULL);
+
       /* let's check if this caps is already in the list, if so let's replace
        * that CodecCap list instead of creating a new one */
       /* we need to compare both media caps and rtp caps */
