@@ -65,18 +65,19 @@ fs_rtp_dtmf_sound_source_build (FsRtpSpecialSource *source,
     FsCodec *selected_codec);
 
 
-static gboolean fs_rtp_dtmf_sound_source_class_want_source (
+static FsCodec *fs_rtp_dtmf_sound_source_get_codec (
     FsRtpSpecialSourceClass *klass,
     GList *negotiated_codecs,
     FsCodec *selected_codec);
 
+
 static void
 fs_rtp_dtmf_sound_source_class_init (FsRtpDtmfSoundSourceClass *klass)
 {
   FsRtpSpecialSourceClass *spsource_class = FS_RTP_SPECIAL_SOURCE_CLASS (klass);
 
   spsource_class->build = fs_rtp_dtmf_sound_source_build;
-  spsource_class->want_source = fs_rtp_dtmf_sound_source_class_want_source;
+  spsource_class->get_codec = fs_rtp_dtmf_sound_source_get_codec;
 
   g_type_class_add_private (klass, sizeof (FsRtpDtmfSoundSourcePrivate));
 }
@@ -94,9 +95,11 @@ fs_rtp_dtmf_sound_source_init (FsRtpDtmfSoundSource *self)
 static gboolean
 _is_law_codec (CodecAssociation *ca, gpointer user_data)
 {
-  if (ca->codec->id == 0 || ca->codec->id == 8)
+  if (codec_association_is_valid_for_sending (ca, FALSE) &&
+      (ca->codec->id == 0 || ca->codec->id == 8))
     return TRUE;
-  else return FALSE;
+  else
+    return FALSE;
 }
 
 /**
@@ -144,15 +147,15 @@ _check_element_factory (gchar *name)
 
   g_return_val_if_fail (name, FALSE);
 
-  fact = gst_element_factory_find ("dtmfsrc");
+  fact = gst_element_factory_find (name);
   if (fact)
     gst_object_unref (fact);
 
   return (fact != NULL);
 }
 
-static gboolean
-fs_rtp_dtmf_sound_source_class_want_source (FsRtpSpecialSourceClass *klass,
+static FsCodec *
+fs_rtp_dtmf_sound_source_get_codec (FsRtpSpecialSourceClass *klass,
     GList *negotiated_codecs,
     FsCodec *selected_codec)
 {
@@ -161,26 +164,25 @@ fs_rtp_dtmf_sound_source_class_want_source (FsRtpSpecialSourceClass *klass,
   gchar *payloader_name = NULL;
 
   if (selected_codec->media_type != FS_MEDIA_TYPE_AUDIO)
-    return FALSE;
+    return NULL;
 
   if (selected_codec->clock_rate != 8000)
-    return FALSE;
+    return NULL;
 
   codec = get_pcm_law_sound_codec (negotiated_codecs,
       &encoder_name, &payloader_name);
   if (!codec)
-    return FALSE;
-
+    return NULL;
 
   if (!_check_element_factory ("dtmfsrc"))
-    return FALSE;
+    return NULL;
 
   if (!_check_element_factory (encoder_name))
-    return FALSE;
+    return NULL;
   if (!_check_element_factory (payloader_name))
-      return FALSE;
+    return NULL;
 
-  return TRUE;
+  return codec;
 }
 
 static GstElement *
@@ -205,6 +207,11 @@ fs_rtp_dtmf_sound_source_build (FsRtpSpecialSource *source,
 
   g_return_val_if_fail (telephony_codec, NULL);
 
+  source->codec = fs_codec_copy (telephony_codec);
+
+  GST_DEBUG ("Creating dtmf sound source for " FS_CODEC_FORMAT,
+      FS_CODEC_ARGS (telephony_codec));
+
   bin = gst_bin_new (NULL);
 
   dtmfsrc = gst_element_factory_make ("dtmfsrc", NULL);
