@@ -58,8 +58,6 @@ typedef struct _FsRtpSpecialSourcePrivate FsRtpSpecialSourcePrivate;
  * FsRtpSpecialSourceClass:
  * @build: The method builds the source #GstElement from the list of negotiated
  *  codecs and selected codecs, it returns %NULL on error
- * @want_source: Returns %TRUE if a source of this type should be created
- *  according to the selected codec and the negotiated codecs
  * @add_blueprint: Adds #CodecBlueprint structs to the list if the proper
  *  elements are installed, the result should always be the same if the elements
  *  installed don't change. It must fill the #CodecBlueprint completely except
@@ -67,8 +65,9 @@ typedef struct _FsRtpSpecialSourcePrivate FsRtpSpecialSourcePrivate;
  *  class, this method is not required.
  * @negotiation_filter: This filters out the invalid CodecAssociation according
  *  to the special source specific rules.
+ * @get_codec: Gets the codec used by this source
  *
- * Class structure for #FsRtpSpecialSource, the build() and want_source()
+ * Class structure for #FsRtpSpecialSource, the build() and get_codec()
  * methods are required.
  */
 
@@ -83,15 +82,15 @@ struct _FsRtpSpecialSourceClass
       FsCodec *selected_codec);
 
    /* Class methods */
-  gboolean (*want_source) (FsRtpSpecialSourceClass *klass,
-      GList *negotiated_codecs,
-      FsCodec *selected_codec);
-
   GList* (*add_blueprint) (FsRtpSpecialSourceClass *klass,
       GList *blueprints);
 
   GList* (*negotiation_filter) (FsRtpSpecialSourceClass *klass,
       GList *codec_associations);
+
+  FsCodec* (*get_codec) (FsRtpSpecialSourceClass *klass,
+      GList *negotiated_codecs,
+      FsCodec *selected_codec);
 };
 
 /**
@@ -108,6 +107,8 @@ struct _FsRtpSpecialSource
    */
   guint order;
 
+  FsCodec *codec;
+
   FsRtpSpecialSourcePrivate *priv;
 };
 
@@ -118,9 +119,7 @@ fs_rtp_special_sources_remove (
     GList **current_extra_sources,
     GList **negotiated_codecs,
     GMutex *mutex,
-    FsCodec *send_codec,
-    GstElement *bin,
-    GstElement *rtpmuxer);
+    FsCodec *send_codec);
 
 void
 fs_rtp_special_sources_create (
