@@ -77,6 +77,13 @@ struct _FsRtpStreamPrivate
   stream_ssrc_added_cb ssrc_added_cb;
   gpointer user_data_for_cb;
 
+  gulong local_candidates_prepared_handler_id;
+  gulong new_active_candidate_pair_handler_id;
+  gulong new_local_candidate_handler_id;
+  gulong error_handler_id;
+  gulong known_source_packet_received_handler_id;
+  gulong state_changed_handler_id;
+
   GMutex *mutex;
 };
 
@@ -143,8 +150,6 @@ static void _state_changed (FsStreamTransmitter *stream_transmitter,
     FsStreamState state,
     gpointer user_data);
 
-
-static GObjectClass *parent_class = NULL;
 // static guint signals[LAST_SIGNAL] = { 0 };
 
 static void
@@ -154,7 +159,6 @@ fs_rtp_stream_class_init (FsRtpStreamClass *klass)
   FsStreamClass *stream_class = FS_STREAM_CLASS (klass);
 
   gobject_class = (GObjectClass *) klass;
-  parent_class = g_type_class_peek_parent (klass);
 
   gobject_class->set_property = fs_rtp_stream_set_property;
   gobject_class->get_property = fs_rtp_stream_get_property;
@@ -188,9 +192,20 @@ fs_rtp_stream_class_init (FsRtpStreamClass *klass)
   g_object_class_override_property (gobject_class,
                                     PROP_SESSION,
                                     "session");
-  g_object_class_override_property (gobject_class,
-                                    PROP_STREAM_TRANSMITTER,
-                                   "stream-transmitter");
+  /**
+   * FsRtpStream:stream-transmitter:
+   *
+   * The #FsStreamTransmitter for this stream.
+   *
+   */
+  g_object_class_install_property (gobject_class,
+      PROP_STREAM_TRANSMITTER,
+      g_param_spec_object ("stream-transmitter",
+        "The transmitter use by the stream",
+        "An FsStreamTransmitter used by this stream",
+        FS_TYPE_STREAM_TRANSMITTER,
+        G_PARAM_CONSTRUCT_ONLY | G_PARAM_WRITABLE | G_PARAM_STATIC_STRINGS));
+
 }
 
 static void
@@ -280,6 +295,19 @@ fs_rtp_stream_dispose (GObject *object)
 
   if (st)
   {
+    g_signal_handler_disconnect (st,
+        self->priv->local_candidates_prepared_handler_id);
+    g_signal_handler_disconnect (st,
+        self->priv->new_active_candidate_pair_handler_id);
+    g_signal_handler_disconnect (st,
+        self->priv->new_local_candidate_handler_id);
+    g_signal_handler_disconnect (st,
+        self->priv->error_handler_id);
+    g_signal_handler_disconnect (st,
+        self->priv->known_source_packet_received_handler_id);
+    g_signal_handler_disconnect (st,
+        self->priv->state_changed_handler_id);
+
     FS_RTP_SESSION_UNLOCK (session);
     fs_stream_transmitter_stop (st);
     g_object_unref (st);
@@ -301,7 +329,7 @@ fs_rtp_stream_dispose (GObject *object)
   g_object_unref (session);
   g_object_unref (session);
 
-  parent_class->dispose (object);
+  G_OBJECT_CLASS (fs_rtp_stream_parent_class)->dispose (object);
 }
 
 static void
@@ -314,7 +342,7 @@ fs_rtp_stream_finalize (GObject *object)
 
   g_mutex_free (self->priv->mutex);
 
-  parent_class->finalize (object);
+  G_OBJECT_CLASS (fs_rtp_stream_parent_class)->finalize (object);
 }
 
 static gboolean
@@ -483,30 +511,36 @@ fs_rtp_stream_constructed (GObject *object)
   g_object_set (self->priv->stream_transmitter, "sending",
     self->priv->direction & FS_DIRECTION_SEND, NULL);
 
-  g_signal_connect (self->priv->stream_transmitter,
-      "local-candidates-prepared",
-      G_CALLBACK (_local_candidates_prepared),
-      self);
-  g_signal_connect (self->priv->stream_transmitter,
-      "new-active-candidate-pair",
-      G_CALLBACK (_new_active_candidate_pair),
-      self);
-  g_signal_connect (self->priv->stream_transmitter,
-      "new-local-candidate",
-      G_CALLBACK (_new_local_candidate),
-      self);
-  g_signal_connect (self->priv->stream_transmitter,
-      "error",
-      G_CALLBACK (_transmitter_error),
-      self);
-  g_signal_connect (self->priv->stream_transmitter,
-      "known-source-packet-received",
-      G_CALLBACK (_known_source_packet_received),
-      self);
-  g_signal_connect (self->priv->stream_transmitter,
-      "state-changed",
-      G_CALLBACK (_state_changed),
-      self);
+  self->priv->local_candidates_prepared_handler_id =
+    g_signal_connect_object (self->priv->stream_transmitter,
+        "local-candidates-prepared",
+        G_CALLBACK (_local_candidates_prepared),
+        self, 0);
+  self->priv->new_active_candidate_pair_handler_id =
+    g_signal_connect_object (self->priv->stream_transmitter,
+        "new-active-candidate-pair",
+        G_CALLBACK (_new_active_candidate_pair),
+        self, 0);
+  self->priv->new_local_candidate_handler_id =
+    g_signal_connect_object (self->priv->stream_transmitter,
+        "new-local-candidate",
+        G_CALLBACK (_new_local_candidate),
+        self, 0);
+  self->priv->error_handler_id =
+    g_signal_connect_object (self->priv->stream_transmitter,
+        "error",
+        G_CALLBACK (_transmitter_error),
+        self, 0);
+  self->priv->known_source_packet_received_handler_id =
+    g_signal_connect_object (self->priv->stream_transmitter,
+        "known-source-packet-received",
+        G_CALLBACK (_known_source_packet_received),
+        self, 0);
+  self->priv->state_changed_handler_id =
+    g_signal_connect_object (self->priv->stream_transmitter,
+        "state-changed",
+        G_CALLBACK (_state_changed),
+        self, 0);
 
   if (!fs_stream_transmitter_gather_local_candidates (
           self->priv->stream_transmitter,
@@ -519,7 +553,8 @@ fs_rtp_stream_constructed (GObject *object)
     return;
   }
 
-  GST_CALL_PARENT (G_OBJECT_CLASS, constructed, (object));
+  if (G_OBJECT_CLASS (fs_rtp_stream_parent_class)->constructed)
+    G_OBJECT_CLASS (fs_rtp_stream_parent_class)->constructed(object);
 }
 
 
@@ -937,16 +972,16 @@ fs_rtp_stream_add_substream_unlock (FsRtpStream *stream,
       "receiving", ((stream->priv->direction & FS_DIRECTION_RECV) != 0),
       NULL);
 
-  g_signal_connect (substream, "unlinked",
-      G_CALLBACK (_substream_unlinked), stream);
-  g_signal_connect (substream, "src-pad-added",
-                    G_CALLBACK (_substream_src_pad_added), stream);
-  g_signal_connect (substream, "codec-changed",
-                    G_CALLBACK (_substream_codec_changed), stream);
-  g_signal_connect (substream, "error",
-                    G_CALLBACK (_substream_error), stream);
+  g_signal_connect_object (substream, "unlinked",
+      G_CALLBACK (_substream_unlinked), stream, 0);
+  g_signal_connect_object (substream, "src-pad-added",
+      G_CALLBACK (_substream_src_pad_added), stream, 0);
+  g_signal_connect_object (substream, "codec-changed",
+      G_CALLBACK (_substream_codec_changed), stream, 0);
+  g_signal_connect_object (substream, "error",
+      G_CALLBACK (_substream_error), stream, 0);
 
-  fs_rtp_sub_stream_verify_codec (substream);
+  fs_rtp_sub_stream_verify_codec_locked (substream);
 
   /* Only announce a pad if it has a codec attached to it */
   if (substream->codec)
