@@ -102,7 +102,7 @@ gboolean fs_rtp_sub_stream_add_output_ghostpad_unlock (
     FsRtpSubStream *substream,
     GError **error);
 
-void fs_rtp_sub_stream_verify_codec (FsRtpSubStream *substream);
+void fs_rtp_sub_stream_verify_codec_locked (FsRtpSubStream *substream);
 
 
 G_END_DECLS
